@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Radicale Server - Calendar Server
-# Copyright © 2008-2011 Guillaume Ayoub
+# Copyright © 2008-2013 Guillaume Ayoub
 # Copyright © 2008 Nicolas Kandel
 # Copyright © 2008 Pascal Halter
 #
@@ -44,23 +44,42 @@ INITIAL_CONFIG = {
         "pid": "",
         "ssl": "False",
         "certificate": "/etc/apache2/ssl/server.crt",
-        "key": "/etc/apache2/ssl/server.key"},
+        "key": "/etc/apache2/ssl/server.key",
+        "dns_lookup": "True",
+        "base_prefix": "/",
+        "realm": "Radicale - Password Required"},
     "encoding": {
         "request": "utf-8",
         "stock": "utf-8"},
-    "acl": {
+    "auth": {
         "type": "None",
         "public_users": "public",
         "private_users": "private",
-        "httpasswd_filename": "/etc/radicale/users",
-        "httpasswd_encryption": "crypt",
+        "htpasswd_filename": "/etc/radicale/users",
+        "htpasswd_encryption": "crypt",
+        "imap_hostname": "localhost",
+        "imap_port": "143",
+        "imap_ssl": "False",
         "ldap_url": "ldap://localhost:389/",
         "ldap_base": "ou=users,dc=example,dc=com",
         "ldap_attribute": "uid",
+        "ldap_filter": "",
         "ldap_binddn": "",
-        "ldap_password": ""},
+        "ldap_password": "",
+        "ldap_scope": "OneLevel",
+        "pam_group_membership": "",
+        "courier_socket": "",
+        "http_url": "",
+        "http_user_parameter": "",
+        "http_password_parameter": ""},
+    "rights": {
+        "type": "None",
+        "file": ""},
     "storage": {
-        "folder": os.path.expanduser("~/.config/radicale/calendars")},
+        "type": "filesystem",
+        "filesystem_folder": os.path.expanduser(
+            "~/.config/radicale/collections"),
+        "database_url": ""},
     "logging": {
         "config": "/etc/radicale/logging",
         "debug": "False",
@@ -76,8 +95,8 @@ for section, values in INITIAL_CONFIG.items():
 
 _CONFIG_PARSER.read("/etc/radicale/config")
 _CONFIG_PARSER.read(os.path.expanduser("~/.config/radicale/config"))
-if 'RADICALE_CONFIG' in os.environ:
-    _CONFIG_PARSER.read(os.environ['RADICALE_CONFIG'])
+if "RADICALE_CONFIG" in os.environ:
+    _CONFIG_PARSER.read(os.environ["RADICALE_CONFIG"])
 
 # Wrap config module into ConfigParser instance
 sys.modules[__name__] = _CONFIG_PARSER
